@@ -21,6 +21,7 @@ from . import _class02_interpolate_all as _interpolate_all
 from . import _class02_operators as _operators
 from . import _class02_plot_as_profile2d as _plot_as_profile2d
 from . import _class02_plot_as_profile2d_compare as _plot_as_profile2d_compare
+from . import _saveload
 
 
 __all__ = ['BSplines2D']
@@ -161,6 +162,32 @@ class BSplines2D(Previous):
             if self.dobj[self._which_bsplines][k0][self._which_mesh] == key:
                 _cropping.add_cropbs_from_crop(coll=self, keybs=k0, keym=key)
 
+    # -----------------
+    # __eq__
+    # ------------------
+
+    def __eq__(self, obj, excluded=None, returnas=None, verb=None):
+
+        # exclude bsplines classes by default
+        wbs = self._which_bsplines
+        lbs = list(self._dobj.get(wbs, {}).keys())
+        exclude_class = tuple([('_dobj', wbs, kbs, 'class') for kbs in lbs])
+
+        # append to existing excluded
+        if excluded is None:
+            excluded = exclude_class
+        else:
+            excluded = list(excluded) + exclude_class
+
+        return super().__eq__(
+            obj,
+            excluded=excluded,
+            returnas=returnas,
+        )
+
+    def __hash__(self, *args, **kargs):
+        return super().__hash__(*args, **kargs)
+
     # -----------------
     # get data subset
     # ------------------
@@ -291,19 +318,45 @@ class BSplines2D(Previous):
 
     def apply_bsplines_operator(
         self,
+        # inputs
         key=None,
+        keybs=None,
+        # operator
         operator=None,
+        geometry=None,
+        # store
         store=None,
+        key_store=None,
+        # returnas
         returnas=None,
     ):
-        """ Apply an operator to desired data """
+        """ Apply an operator on desired quantity
+
+        key can be a list of data with the same bsplines
+
+        Notes:
+            * Only works for D0N1 so far
+            * Works with and w/o cropbs
+            * Does not work with subkey so far
+
+        Computes data, ref and units
+        Returns as dict
+        Optionally store result
+
+        """
 
-        raise NotImplementedError("TBD")
         return _operators.apply_operator(
             coll=self,
+            # inputs
             key=key,
+            keybs=keybs,
+            # operator
             operator=operator,
+            geometry=geometry,
+            # store
             store=store,
+            key_store=key_store,
+            # returnas
             returnas=returnas,
         )
 
@@ -944,6 +997,7 @@ class BSplines2D(Previous):
         dref_vectorZ=None,
         dref_vectorU=None,
         ref_vector_strategy=None,
+        uniform=None,
         # interpolation
         val_out=None,
         nan0=None,
@@ -959,6 +1013,7 @@ class BSplines2D(Previous):
         # interactivity
         dinc=None,
         connect=None,
+        show_commands=None,
     ):
 
         return _plot_as_profile2d.plot_as_profile2d(
@@ -976,6 +1031,7 @@ class BSplines2D(Previous):
             dref_vectorZ=dref_vectorZ,
             dref_vectorU=dref_vectorU,
             ref_vector_strategy=ref_vector_strategy,
+            uniform=uniform,
             # interpolation
             val_out=val_out,
             nan0=nan0,
@@ -991,6 +1047,7 @@ class BSplines2D(Previous):
             # interactivity
             dinc=dinc,
             connect=connect,
+            show_commands=show_commands,
         )
 
     def plot_as_profile2d_compare(
@@ -1006,6 +1063,8 @@ class BSplines2D(Previous):
         # ref vectors
         dref_vectorZ=None,
         dref_vectorU=None,
+        ref_vector_strategy=None,
+        uniform=None,
         # interpolation
         val_out=None,
         nan0=None,
@@ -1021,6 +1080,7 @@ class BSplines2D(Previous):
         # interactivity
         dinc=None,
         connect=None,
+        show_commands=None,
     ):
 
         return _plot_as_profile2d_compare.plot_as_profile2d_compare(
@@ -1036,6 +1096,8 @@ class BSplines2D(Previous):
             # ref vectors
             dref_vectorZ=dref_vectorZ,
             dref_vectorU=dref_vectorU,
+            ref_vector_strategy=ref_vector_strategy,
+            uniform=uniform,
             # interpolation
             val_out=val_out,
             nan0=nan0,
@@ -1051,6 +1113,7 @@ class BSplines2D(Previous):
             # interactivity
             dinc=dinc,
             connect=connect,
+            show_commands=show_commands,
         )
 
 
@@ -1089,3 +1152,32 @@ class BSplines2D(Previous):
             # fs=fs,
             # dleg=dleg,
         # )
+
+    # -----------------
+    # save
+    # ------------------
+
+    def save(
+        self,
+        path=None,
+        name=None,
+        sep=None,
+        verb=True,
+        return_pfe=False,
+    ):
+
+        # ------------------------------
+        # bsplines-specific preparation
+
+        _saveload.prepare_bsplines(self)
+
+        # ---------------------
+        # call inherited method
+
+        return super().save(
+            path=path,
+            name=name,
+            sep=sep,
+            verb=verb,
+            return_pfe=return_pfe,
+        )
\ No newline at end of file
