@@ -7,6 +7,7 @@ import warnings
 
 # Common
 import numpy as np
+from matplotlib.path import Path
 import datastock as ds
 
 
@@ -100,6 +101,7 @@ def interpolate(
     # isbs
 
     x0_str = None
+    crop_path = None
     if isbs:
 
         # -----------------
@@ -136,10 +138,35 @@ def interpolate(
         if details is True:
             ref_com, domain = None, None
 
+        if mtype == 'rect' and crop is not None:
+            doutline = coll.get_mesh_outline(keym)
+            crop_path = Path(
+                np.array([doutline['x0']['data'], doutline['x1']['data']]).T
+            )
+
+        # # no x0 + no res + deg = 1 bsplines => x0 = knots
+        wm = coll._which_mesh
+        wbs = coll._which_bsplines
+        deg = coll.dobj[wbs][keybs]['deg']
+        if x0 is None and res is None and deg == 1:
+            subbs = coll.dobj[wm][keym].get('subbs')
+            if (
+                submesh is True
+                and subbs is not None
+                and coll.dobj[wbs][subbs]['deg'] == 1
+            ):
+                bsx0 = subbs
+            elif submesh is False or subbs is None:
+                bsx0 = keybs
+
+            kx01 = coll.dobj[bsx0]['apex']
+            x0 = coll.ddata[kx01[0]]['data']
+            if len(kx01) == 2:
+                x1 = coll.ddata[kx01[1]]['data']
+
         # ---------------
         # no x0 => mesh
 
-        wm = coll._which_mesh
         if x0 is None:
             if submesh is True:
                 km = coll.dobj[wm][keym]['submesh']
@@ -279,17 +306,24 @@ def interpolate(
     if isbs:
 
         _interp(
+            # resources
             coll=coll,
             keybs=keybs,
             keys=keys,
+            # interpolation points
             x0=x0,
             x1=x1,
+            # options
             val_out=val_out,
             deriv=deriv,
             indbs_tf=indbs_tf,
+            # cropping
             crop=crop,
             cropbs=cropbs,
+            crop_path=crop_path,
+            # details
             details=details,
+            # others
             dout=dout,
             mtype=mtype,
             ddata=ddata,
@@ -350,8 +384,8 @@ def interpolate(
         #     )
         #     err.args = (msg,)
         #     raise err
-            
-            
+
+
     # ----------
     # store
 
@@ -930,6 +964,7 @@ def _interp(
     indbs_tf=None,
     crop=None,
     cropbs=None,
+    crop_path=None,
     details=None,
     dout=None,
     mtype=None,
@@ -1026,6 +1061,7 @@ def _interp(
                     # rect-specific
                     crop=crop,
                     cropbs=cropbs,
+                    crop_path=crop_path,
                     # slicing
                     sli_c=sli_c,
                     sli_x=sli_x,
@@ -2089,4 +2125,4 @@ def get_bsplines_operator(
     elif 'N2' in operator:
         ref = (keycropped, keycropped)
 
-    return opmat, operator, geometry, dim, ref, crop, store, returnas, key
+    return opmat, operator, geometry, dim, ref, crop, store, returnas, key
\ No newline at end of file
