@@ -3,6 +3,7 @@ This module contains tests for tofu.geom in its structured version
 """
 
 # Built-in
+import os
 import itertools as itt
 
 
@@ -14,6 +15,7 @@ import numpy as np
 from . import test_input
 from .. import _class01_checks_2d_rect as _checks
 from .._class03_Bins import Bins as BSplines2D
+from .. import _saveload
 
 
 #######################################################
@@ -325,26 +327,51 @@ class Test01_BSplines2D():
             kind=None,
         )
 
+    def test54_plot_as_profile2d_compare(self):
+        test_input._plot_as_profile2d_compare(
+            self.bs,
+            nd='2d',
+            kind=None,
+        )
+
     # ################################
     # operators
     # ################################
 
-    def test54_operators_1d(self):
+    def test55_operators_1d(self):
         test_input._get_operators(
             self.bs,
             nd='1d',
             kind=None,
         )
 
-    def test55_operators_2d_rect(self):
+    def test56_operators_2d_rect(self):
         test_input._get_operators(
             self.bs,
             nd='2d',
             kind='rect',
         )
 
-    def test56_operators_2d_tri(self):
+    def test57_operators_2d_tri(self):
         pass
 
-    def test57_operators_1d_subkey(self):
+    def test58_operators_1d_subkey(self):
         pass
+
+    # ################################
+    # saving / loading
+    # ################################
+
+    def test59_saveload_equal(self):
+
+        # save
+        pfe = self.bs.save(return_pfe=True)
+
+        # load
+        out = _saveload.load(pfe)
+
+        # remove file
+        os.remove(pfe)
+
+        # equal
+        assert self.bs == out
\ No newline at end of file
